@@ -1,10 +1,9 @@
-use jsonrpsee::{
-	proc_macros::rpc,
-	types::{async_trait, RpcResult},
-	ws_server::{SubscriptionSink, WsServerBuilder},
-};
 use std::net::SocketAddr;
 
+use jsonrpsee::proc_macros::rpc;
+use jsonrpsee::core::{async_trait, RpcResult};
+use jsonrpsee::ws_server::{SubscriptionSink, WsServerBuilder};
+
 #[rpc(server)]
 pub trait Rpc {
 	#[method(name = "foo")]
